<?php

$anio = date('Y');
$notifi = new App\Controladores\NotificacionesControlador();
$factu = new App\Modelos\Generico;
$woocomm = new \App\Controladores\GenericoControlador;

$nota_pendientes = [];
$factura_pendiente = [];
$pedido_empres_pendiente = [];
$presupuesto_pendiente = [];
$pedidos_woocommerce = $woocomm->woocommerce();
$notificaciones = $notifi->obtenerNotificacionesHeader();


if ($_SESSION['sucursal']['id'] != 0) {
    $sucursal = $factu->obtenerSucursales($_SESSION['sucursal']['id']);

    if ($sucursal) {
        $nota_pendientes = $factu->obtenerNotasdeEntregaAnualesPendientess("YEAR(ne.ne_fecha)=" . $anio . " AND ne.ne_surcid={$sucursal['su_id']}");
        $factura_pendiente = $factu->obtenerFacturasAnualesPendientess("YEAR(fm.fm_fecha)=" . $anio . " AND fm.fm_surcid={$sucursal['su_id']}");
        $pedido_empres_pendiente = $factu->obtenerPedidosAnualesPendientess("YEAR(pe.pe_fecha)=" . $anio . " AND pe.pe_surcid={$sucursal['su_id']}");
        $presupuesto_pendiente = $factu->obtenerPresupuestosAnualesPendientess("YEAR(pre.pre_fecha)=" . $anio . " AND pre.pre_surcid={$sucursal['su_id']}");
    }
} else {
    $nota_pendientes = $factu->obtenerNotasdeEntregaAnualesPendientess("YEAR(ne.ne_fecha)=" . $anio);
    $factura_pendiente = $factu->obtenerFacturasAnualesPendientess("YEAR(fm.fm_fecha)=" . $anio);
    $pedido_empres_pendiente = $factu->obtenerPedidosAnualesPendientess("YEAR(pe.pe_fecha)=" . $anio);
    $presupuesto_pendiente = $factu->obtenerPresupuestosAnualesPendientess("YEAR(pre.pre_fecha)=" . $anio);
}


?>
<div class="main-header">
    <div class="logo-header" data-background-color="blue2">
        <a href="<?= ruta_base() ?>" class="logo">
            <img src="<?= ((date('m') == 12)) ? asset('assets/img/pagina_gn_navidad.png') : asset('assets/img/pagina_gn.png') ?>" alt="navbar brand" class="navbar-brand" height="35">
        </a>
        <button class="navbar-toggler sidenav-toggler ml-auto" type="button" data-toggle="collapse" data-target="collapse" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon  text-muted">
                <i class="fa fa-bars  text-muted"></i>
            </span>
        </button>
        <button class="topbar-toggler more"><i class="fa fa-bars"></i></button>
        <div class="nav-toggle">
            <button class="btn btn-toggle sidenav-overlay-toggler toggled"><i class="fa fa-bars"></i></button>
        </div>
    </div>
    <nav class="navbar navbar-header navbar-expand-lg" data-background-color="blue2">
        <div class="container-fluid">
            <div class="collapse" id="search-nav" style="max-width: 400px;">
                <span class="text-light"> <a href="<?= ruta_base() ?>" class="btn-secondary"><?= constant('APP_DESCRIPTION'); ?><a/></span>
            </div>
            <ul class="navbar-nav topbar-nav ml-md-auto align-items-center">
                <li class="nav-item toggle-nav-search hidden-caret">
                    <a class="nav-link" data-toggle="collapse" href="#search-nav" role="button" aria-expanded="false" aria-controls="search-nav">
                        <i class="fa fa-search"></i>
                    </a>
                </li>
                
                <?php if ($_SESSION['user_data']['emp_tipo'] === NULL) : ?>
                    <li class="nav-item dropdown hidden-caret">
                        <a class="nav-link dropdown-toggle" href="#" id="notifDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                            <i class="fa fa-bell"></i>
                            <span class="notification"><?= count($notificaciones) ?></span>
                        </a>
                        <ul class="dropdown-menu notif-box animated fadeIn" aria-labelledby="notifDropdown">
                            <li>
                                <a class="see-all" href="#">
                                    <div class="dropdown-title"><?= count($notificaciones) ?> notificaciones nuevas </div><i class="fa fa-angle-right"></i>
                                </a>
                            </li>
                            <li>
                                <div class="scroll-wrapper notif-scroll scrollbar-outer">
                                    <div class="notif-scroll scrollbar-outer">
                                        <div class="notif-center">
                                            <a href="<?php url('woocommerce') ?>">
                                                <div class="notif-icon"><small><i class="fa fa-store"></i></small></div>
                                                <div class="notif-content">
                                                    <span class="block">Pedidos woocommerce</span>
                                                    <span class="time"><i class="text-warning fas fa-info-circle" title="Pendiente"></i> <?= $pedidos_woocommerce ?></span>

                                                </div>
                                            </a>
                                        </div>
                                        <div class="notif-center">
                                            <a href="<?php url('facturacion') ?>">
                                                <div class="notif-icon"><small><i class=" fa fa-cart-plus"></i></small></div>
                                                <div class="notif-content">
                                                    <span class="block">Nota de entrega</span>
                                                    <span class="time"><i class="text-warning fas fa-info-circle" title="Pendiente"></i> <?= count($nota_pendientes) ?></span>
                                                </div>
                                            </a>
                                        </div>
                                        <div class="notif-center">
                                            <a href="<?php url('facturacion') ?>">
                                                <div class="notif-icon"><small><i class="fa fa-cart-plus"></i></small></div>
                                                <div class="notif-content">
                                                    <span class="block">Facturas</span>
                                                    <span class="time"><i class="text-warning fas fa-info-circle" title="Pendiente"></i> <?= count($factura_pendiente) ?></span>
                                                </div>
                                            </a>
                                        </div>
                                        <div class="notif-center">
                                            <a href="<?php url('facturacion') ?>">
                                                <div class="notif-icon"><small><i class="fa fa-cart-plus"></i></small></div>
                                                <div class="notif-content">
                                                    <span class="block">Presupuestos</span>
                                                    <span class="time"><i class="text-warning fas fa-info-circle" title="Pendiente"></i> <?= count($presupuesto_pendiente) ?></span>
                                                </div>
                                            </a>
                                        </div>
                                        <div class="notif-center">
                                            <a href="<?php url('facturacion') ?>">
                                                <div class="notif-icon"><small><i class="fa fa-cart-plus"></i></small></div>
                                                <div class="notif-content">
                                                    <span class="block">Pedidos</span>
                                                    <span class="time"><i class="text-warning fas fa-info-circle" title="Pendiente"></i> <?= count($pedido_empres_pendiente) ?></span>
                                                </div>
                                            </a>
                                        </div>
                                    </div>
                                </div>
                            </li>
                        </ul>
                    </li>
                <?php endif; ?>

                <li class="nav-item dropdown hidden-caret">
                    <a class="dropdown-toggle profile-pic" data-toggle="dropdown" href="#" aria-expanded="false">
                        <div class="avatar-sm" id="img_perfil_principal">
                            <?php if (!is_null($_SESSION['user_data']['einfo_imagen']) || $_SESSION['user_data']['einfo_imagen'] != '') : ?>
                                <img src="<?= constant('IMG_URI') ?>empleados/<?= $_SESSION['user_data']['einfo_imagen']; ?>" alt="Imagen de perfil" class="avatar-img rounded-circle">
                            <?php else : ?>
                                <img src="<?= ruta_base() ?>public/assets/img/default.png" alt="Imagen de perfil" class="avatar-img rounded-circle">
                            <?php endif; ?>
                        </div>
                    </a>
                    <ul class="dropdown-menu dropdown-user animated fadeIn">
                        <div class="scroll-wrapper">
                            <div class="dropdown-user-scroll">
                                <li>
                                    <div class="user-box">
                                        <div class="avatar-lg" id="img_perfil_secundario">
                                            <?php if (!is_null($_SESSION['user_data']['einfo_imagen']) || $_SESSION['user_data']['einfo_imagen'] != '') : ?>
                                                <img src="<?= constant('IMG_URI') ?>empleados/<?= $_SESSION['user_data']['einfo_imagen']; ?>" alt="Imagen de perfil" class="avatar-img rounded">
                                            <?php else : ?>
                                                <img src="<?= ruta_base() ?>public/assets/img/default.png" alt="Imagen de perfil" class="avatar-img rounded">
                                            <?php endif; ?>
                                        </div>
                                        <div class="u-text">
                                            <h4><?= $_SESSION['user_data']['einfo_apellidos']; ?></h4>
                                            <p class="text-muted"><?= $_SESSION['user_data']['einfo_email']; ?></p>
                                        </div>
                                    </div>
                                </li>
                                <li>
                                    <div class="dropdown-divider"></div>
                                    <a class="dropdown-item" href="<?= url('miperfil') ?>">Mi Perfil</a>
                                    <div class="dropdown-divider"></div>
                                    <a class="dropdown-item" href="<?php url('login/salir'); ?>">Salir</a>
                                </li>
                            </div>
                        </div>
                    </ul>
                </li>
            </ul>
        </div>
    </nav>

</div>

<div class="main-panel">